@@ -98,6 +98,11 @@ cl(["-I", Dir|T]) ->
 cl(["-I"++Dir|T]) ->
   append_include(Dir),
   cl(T);
+cl(["--input_list_file"]) ->
+  cl_error("No input list file specified");
+cl(["--input_list_file",File|L]) ->
+  read_input_list_file(File),
+  cl(L);
 cl(["-c"++_|T]) ->
   NewTail = command_line(T),
   cl(NewTail);
@@ -244,6 +249,16 @@ command_line(T0) ->
   end,
   T.
 
+read_input_list_file(File) ->
+  case file:read_file(File) of
+    {ok,Bin} ->
+      Files = binary:split(Bin, <<"\n">>, [trim_all,global]),
+      NewFiles = [binary_to_list(string:trim(F)) || F <- Files],
+      append_var(dialyzer_options_files, NewFiles);
+    {error,Reason} ->
+      cl_error(io_lib:format("Reading of ~s failed: ~s", [File,file:format_error(Reason)]))
+  end.
+
 -spec cl_error(deep_string()) -> no_return().
 
 cl_error(Str) ->
@@ -395,6 +410,9 @@ Options:
       Same as the previous but the specified directories are searched
       recursively for subdirectories containing .erl or .beam files in
       them, depending on the type of analysis.
+  --input_list_file file
+      Specify the name of a file that contains the names of the files
+      to be analyzed (one file name per line).
   --apps applications
       Option typically used when building or modifying a plt as in:
         dialyzer --build_plt --apps erts kernel stdlib mnesia ...
